-------------------------------------------------------------------------------
--! @file       InvSbox.vhd
--! @author     William Diehl
--! @brief      SCREAM InvSbox
--! @date       29 July 2016
-------------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.numeric_std.all;
use ieee.std_logic_unsigned.all;

entity InvSbox is
	port(
	 x_in: in STD_LOGIC_VECTOR(127 DOWNTO 0);
    x_out: out STD_LOGIC_VECTOR(127 DOWNTO 0)
	 --inv : in std_logic -- inv=0 is Sbox; inv=1 is InvSbox
	 );
	 
end InvSbox;

architecture structural of InvSbox is

SIGNAL	x0:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x1:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x2:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x3:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x4:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x5:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x6:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	x7:	STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL	w0:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w1:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w2:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w3:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w4:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w5:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w6:	STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL	w7:	STD_LOGIC_VECTOR(15 DOWNTO 0);

SIGNAL	s4, s5, s6, s7 : STD_LOGIC_VECTOR(15 DOWNTO 0);
SIGNAL  t01, nt01, t1, t03, nt03, t3 : STD_LOGIC_VECTOR(15 DOWNTO 0);

begin

x0 <= X_IN(127 DOWNTO 112);
x1 <= X_IN(111 DOWNTO 96);
x2 <= X_IN(95 DOWNTO 80);
x3 <= X_IN(79 DOWNTO 64);
x4 <= X_IN(63 DOWNTO 48);
x5 <= X_IN(47 DOWNTO 32);
x6 <= X_IN(31 DOWNTO 16);
x7 <= X_IN(15 DOWNTO 0);

t01 <= (x1 and x2) xor x0;
nt01 <= not t01;
--t1 <= t01 when (inv = '0') else nt01;

Feistel_round_1: entity work.Feistel_A(dataflow)

   port map(
	t0 => nt01,
	x1 => x1,
	x2 => x2,
	x3 => x3,
	x4 => x4,
	x5 => x5,
	x6 => x6,
	x7 => x7,
	w4 => s4,
	w5 => s5,
	w6 => s6,
	w7 => s7);

Feistel_round_2: entity work.Feistel_B(dataflow)

   port map(
	x0 => x0,
	x1 => x1,
	x2 => x2,
	x3 => x3,
	x4 => s4,
	x5 => s5,
	x6 => s6,
	x7 => s7,
	w0 => w0,
	w1 => w1,
	w2 => w2,
	w3 => w3);

t03 <= (w1 and w2) xor w0; 
--nt03 <= not t03;
--t3 <= nt03 when (inv = '0') else t03;

Feistel_round_3: entity work.Feistel_A(dataflow)

   port map(
	t0 => t03,
	x1 => w1,
	x2 => w2,
	x3 => w3,
	x4 => s4,
	x5 => s5,
	x6 => s6,
	x7 => s7,
	w4 => w4,
	w5 => w5,
	w6 => w6,
	w7 => w7);

x_out <= w0 & w1 & w2 & w3 & w4 & w5 & w6 & w7;

end structural;