-------------------------------------------------------------------------------
--! @file       LBox_1.vhd
--! @author     William Diehl
--! @brief      SCREAM LBox_1
--! @date       29 July 2016
-------------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.numeric_std.all;

ENTITY LBox_1 IS

	PORT(
		Addr: IN STD_LOGIC_VECTOR(7 DOWNTO 0);
		Dout: OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
	);

END LBox_1;

ARCHITECTURE dataflow OF LBox_1 IS

SIGNAL index: INTEGER RANGE 0 TO 255;
TYPE vector_array IS ARRAY (0 to 255) OF STD_LOGIC_VECTOR(15 DOWNTO 0);
CONSTANT memory : vector_array := 
	(

	x"0000", x"385c", x"52a9", x"6af5", x"7bb3", x"43ef", x"291a", x"1146",
	x"96c1", x"ae9d", x"c468", x"fc34", x"ed72", x"d52e", x"bfdb", x"8787",
	x"d76d", x"ef31", x"85c4", x"bd98", x"acde", x"9482", x"fe77", x"c62b",
	x"41ac", x"79f0", x"1305", x"2b59", x"3a1f", x"0243", x"68b6", x"50ea",
	x"3ae0", x"02bc", x"6849", x"5015", x"4153", x"790f", x"13fa", x"2ba6",
	x"ac21", x"947d", x"fe88", x"c6d4", x"d792", x"efce", x"853b", x"bd67",
	x"ed8d", x"d5d1", x"bf24", x"8778", x"963e", x"ae62", x"c497", x"fccb",
	x"7b4c", x"4310", x"29e5", x"11b9", x"00ff", x"38a3", x"5256", x"6a0a",
	x"e524", x"dd78", x"b78d", x"8fd1", x"9e97", x"a6cb", x"cc3e", x"f462",
	x"73e5", x"4bb9", x"214c", x"1910", x"0856", x"300a", x"5aff", x"62a3",
	x"3249", x"0a15", x"60e0", x"58bc", x"49fa", x"71a6", x"1b53", x"230f",
	x"a488", x"9cd4", x"f621", x"ce7d", x"df3b", x"e767", x"8d92", x"b5ce",
	x"dfc4", x"e798", x"8d6d", x"b531", x"a477", x"9c2b", x"f6de", x"ce82",
	x"4905", x"7159", x"1bac", x"23f0", x"32b6", x"0aea", x"601f", x"5843",
	x"08a9", x"30f5", x"5a00", x"625c", x"731a", x"4b46", x"21b3", x"19ef",
	x"9e68", x"a634", x"ccc1", x"f49d", x"e5db", x"dd87", x"b772", x"8f2e",
	x"fea5", x"c6f9", x"ac0c", x"9450", x"8516", x"bd4a", x"d7bf", x"efe3",
	x"6864", x"5038", x"3acd", x"0291", x"13d7", x"2b8b", x"417e", x"7922",
	x"29c8", x"1194", x"7b61", x"433d", x"527b", x"6a27", x"00d2", x"388e",
	x"bf09", x"8755", x"eda0", x"d5fc", x"c4ba", x"fce6", x"9613", x"ae4f",
	x"c445", x"fc19", x"96ec", x"aeb0", x"bff6", x"87aa", x"ed5f", x"d503",
	x"5284", x"6ad8", x"002d", x"3871", x"2937", x"116b", x"7b9e", x"43c2",
	x"1328", x"2b74", x"4181", x"79dd", x"689b", x"50c7", x"3a32", x"026e",
	x"85e9", x"bdb5", x"d740", x"ef1c", x"fe5a", x"c606", x"acf3", x"94af",
	x"1b81", x"23dd", x"4928", x"7174", x"6032", x"586e", x"329b", x"0ac7",
	x"8d40", x"b51c", x"dfe9", x"e7b5", x"f6f3", x"ceaf", x"a45a", x"9c06",
	x"ccec", x"f4b0", x"9e45", x"a619", x"b75f", x"8f03", x"e5f6", x"ddaa",
	x"5a2d", x"6271", x"0884", x"30d8", x"219e", x"19c2", x"7337", x"4b6b",
	x"2161", x"193d", x"73c8", x"4b94", x"5ad2", x"628e", x"087b", x"3027",
	x"b7a0", x"8ffc", x"e509", x"dd55", x"cc13", x"f44f", x"9eba", x"a6e6",
	x"f60c", x"ce50", x"a4a5", x"9cf9", x"8dbf", x"b5e3", x"df16", x"e74a",
	x"60cd", x"5891", x"3264", x"0a38", x"1b7e", x"2322", x"49d7", x"718b"

);

BEGIN

	index <= to_integer(unsigned(Addr));
	Dout <= memory(index);

END dataflow;