-------------------------------------------------------------------------------
--! @file       LBox_2.vhd
--! @author     William Diehl
--! @brief      SCREAM LBox_2
--! @date       29 July 2016
-------------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.numeric_std.all;

ENTITY LBox_2 IS

	PORT(
		Addr: IN STD_LOGIC_VECTOR(7 DOWNTO 0);
		Dout: OUT STD_LOGIC_VECTOR(15 DOWNTO 0)
	);

END LBox_2;

ARCHITECTURE dataflow OF LBox_2 IS

SIGNAL index: INTEGER RANGE 0 TO 255;
TYPE vector_array IS ARRAY (0 to 255) OF STD_LOGIC_VECTOR(15 DOWNTO 0);
CONSTANT memory : vector_array := 
	(

	x"0000", x"464b", x"f1af", x"b7e4", x"a133", x"e778", x"509c", x"16d7",
	x"7f74", x"393f", x"8edb", x"c890", x"de47", x"980c", x"2fe8", x"69a3",
	x"6712", x"2159", x"96bd", x"d0f6", x"c621", x"806a", x"378e", x"71c5",
	x"1866", x"5e2d", x"e9c9", x"af82", x"b955", x"ff1e", x"48fa", x"0eb1",
	x"7a6f", x"3c24", x"8bc0", x"cd8b", x"db5c", x"9d17", x"2af3", x"6cb8",
	x"051b", x"4350", x"f4b4", x"b2ff", x"a428", x"e263", x"5587", x"13cc",
	x"1d7d", x"5b36", x"ecd2", x"aa99", x"bc4e", x"fa05", x"4de1", x"0baa",
	x"6209", x"2442", x"93a6", x"d5ed", x"c33a", x"8571", x"3295", x"74de",
	x"701b", x"3650", x"81b4", x"c7ff", x"d128", x"9763", x"2087", x"66cc",
	x"0f6f", x"4924", x"fec0", x"b88b", x"ae5c", x"e817", x"5ff3", x"19b8",
	x"1709", x"5142", x"e6a6", x"a0ed", x"b63a", x"f071", x"4795", x"01de",
	x"687d", x"2e36", x"99d2", x"df99", x"c94e", x"8f05", x"38e1", x"7eaa",
	x"0a74", x"4c3f", x"fbdb", x"bd90", x"ab47", x"ed0c", x"5ae8", x"1ca3",
	x"7500", x"334b", x"84af", x"c2e4", x"d433", x"9278", x"259c", x"63d7",
	x"6d66", x"2b2d", x"9cc9", x"da82", x"cc55", x"8a1e", x"3dfa", x"7bb1",
	x"1212", x"5459", x"e3bd", x"a5f6", x"b321", x"f56a", x"428e", x"04c5",
	x"8ab1", x"ccfa", x"7b1e", x"3d55", x"2b82", x"6dc9", x"da2d", x"9c66",
	x"f5c5", x"b38e", x"046a", x"4221", x"54f6", x"12bd", x"a559", x"e312",
	x"eda3", x"abe8", x"1c0c", x"5a47", x"4c90", x"0adb", x"bd3f", x"fb74",
	x"92d7", x"d49c", x"6378", x"2533", x"33e4", x"75af", x"c24b", x"8400",
	x"f0de", x"b695", x"0171", x"473a", x"51ed", x"17a6", x"a042", x"e609",
	x"8faa", x"c9e1", x"7e05", x"384e", x"2e99", x"68d2", x"df36", x"997d",
	x"97cc", x"d187", x"6663", x"2028", x"36ff", x"70b4", x"c750", x"811b",
	x"e8b8", x"aef3", x"1917", x"5f5c", x"498b", x"0fc0", x"b824", x"fe6f",
	x"faaa", x"bce1", x"0b05", x"4d4e", x"5b99", x"1dd2", x"aa36", x"ec7d",
	x"85de", x"c395", x"7471", x"323a", x"24ed", x"62a6", x"d542", x"9309",
	x"9db8", x"dbf3", x"6c17", x"2a5c", x"3c8b", x"7ac0", x"cd24", x"8b6f",
	x"e2cc", x"a487", x"1363", x"5528", x"43ff", x"05b4", x"b250", x"f41b",
	x"80c5", x"c68e", x"716a", x"3721", x"21f6", x"67bd", x"d059", x"9612",
	x"ffb1", x"b9fa", x"0e1e", x"4855", x"5e82", x"18c9", x"af2d", x"e966",
	x"e7d7", x"a19c", x"1678", x"5033", x"46e4", x"00af", x"b74b", x"f100",
	x"98a3", x"dee8", x"690c", x"2f47", x"3990", x"7fdb", x"c83f", x"8e74"




);

BEGIN

	index <= to_integer(unsigned(Addr));
	Dout <= memory(index);

END dataflow;